@@ -150,7 +150,7 @@ grl_filesystem_plugin_init (GrlRegistry *registry,
                             GrlPlugin *plugin,
                             GList *configs)
 {
-  GrlConfig *config;
+  GrlFilesystemSource *source;
   GList *chosen_uris = NULL;
   guint max_search_depth = GRILO_CONF_MAX_SEARCH_DEPTH_DEFAULT;
   gboolean handle_pls = FALSE;
@@ -163,14 +163,15 @@ grl_filesystem_plugin_init (GrlRegistry *registry,
   bindtextdomain (GETTEXT_PACKAGE, LOCALEDIR);
   bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 
-  GrlFilesystemSource *source = grl_filesystem_source_new ();
+  source = grl_filesystem_source_new ();
 
   for (; configs; configs = g_list_next (configs)) {
+    GrlConfig *config = configs->data;
     gchar *uri;
-    config = GRL_CONFIG (configs->data);
+
     uri = grl_config_get_string (config, GRILO_CONF_CHOSEN_URI);
     if (uri) {
-      chosen_uris = g_list_append (chosen_uris, uri);
+      chosen_uris = g_list_prepend (chosen_uris, uri);
     }
     if (grl_config_has_param (config, GRILO_CONF_MAX_SEARCH_DEPTH)) {
       max_search_depth = (guint)grl_config_get_int (config, GRILO_CONF_MAX_SEARCH_DEPTH);
@@ -179,7 +180,7 @@ grl_filesystem_plugin_init (GrlRegistry *registry,
       handle_pls = grl_config_get_boolean (config, GRILO_CONF_HANDLE_PLS);
     }
   }
-  source->priv->chosen_uris = chosen_uris;
+  source->priv->chosen_uris = g_list_reverse (chosen_uris);
   source->priv->max_search_depth = max_search_depth;
   source->priv->handle_pls = handle_pls;
 
