@@ -166,6 +166,8 @@ GRL_PLUGIN_DEFINE (GRL_MAJOR,
 
 /* ================== GrlOpenSubtitles GObject ================ */
 
+G_DEFINE_TYPE_WITH_PRIVATE (GrlOpenSubtitlesSource, grl_opensubtitles_source, GRL_TYPE_SOURCE)
+
 static GrlOpenSubtitlesSource *
 grl_opensubtitles_source_new (void)
 {
@@ -189,28 +191,23 @@ grl_opensubtitles_source_class_init (GrlOpenSubtitlesSourceClass * klass)
   source_class->resolve = grl_opensubtitles_source_resolve;
 
   gobject_class->finalize = grl_opensubtitles_source_finalize;
-
-  g_type_class_add_private (klass, sizeof (GrlOpenSubtitlesSourcePriv));
 }
 
 static void
 grl_opensubtitles_source_init (GrlOpenSubtitlesSource *source)
 {
-  GrlOpenSubtitlesSourcePriv *priv = GRL_OPENSUBTITLES_SOURCE_GET_PRIVATE (source);
+  GrlOpenSubtitlesSourcePrivate *priv = grl_opensubtitles_source_get_instance_private (source);
 
+  source->priv = priv;
   priv->session = soup_session_new ();
   priv->queue = g_async_queue_new ();
 }
 
-G_DEFINE_TYPE (GrlOpenSubtitlesSource,
-               grl_opensubtitles_source,
-               GRL_TYPE_SOURCE);
-
 static void
 grl_opensubtitles_source_finalize (GObject *object)
 {
   GrlOpenSubtitlesSource *source = GRL_OPENSUBTITLES_SOURCE (object);
-  GrlOpenSubtitlesSourcePriv *priv = GRL_OPENSUBTITLES_SOURCE_GET_PRIVATE (source);
+  GrlOpenSubtitlesSourcePrivate *priv = source->priv;
 
   GRL_DEBUG ("%s", G_STRFUNC);
 
@@ -224,7 +221,7 @@ grl_opensubtitles_source_finalize (GObject *object)
 /* ======================= Utilities ==================== */
 
 static void
-ensure_hash_keyid (GrlOpenSubtitlesSourcePriv *priv)
+ensure_hash_keyid (GrlOpenSubtitlesSourcePrivate *priv)
 {
   if (priv->hash_keyid == GRL_METADATA_KEY_INVALID) {
     GrlRegistry *registry = grl_registry_get_default ();
@@ -515,11 +512,10 @@ login_done_cb (SoupSession *session,
 	       SoupMessage *msg,
 	       gpointer     user_data)
 {
-  GrlOpenSubtitlesSourcePriv *priv =
-    GRL_OPENSUBTITLES_SOURCE_GET_PRIVATE (user_data);
   gboolean failed = FALSE;
   GrlSourceResolveSpec *rs;
   GError *error = NULL;
+  GrlOpenSubtitlesSourcePrivate *priv = GRL_OPENSUBTITLES_SOURCE(user_data)->priv;
 
   if (msg->status_code != 200) {
     GRL_DEBUG ("Failed to login: HTTP code %d", msg->status_code);
@@ -575,8 +571,7 @@ grl_opensubtitles_source_may_resolve (GrlSource *source,
                                       GrlKeyID   key_id,
                                       GList    **missing_keys)
 {
-  GrlOpenSubtitlesSourcePriv *priv =
-    GRL_OPENSUBTITLES_SOURCE_GET_PRIVATE (source);
+  GrlOpenSubtitlesSourcePrivate *priv = GRL_OPENSUBTITLES_SOURCE(source)->priv;
 
   ensure_hash_keyid (priv);
   if (priv->hash_keyid == GRL_METADATA_KEY_INVALID)
@@ -625,8 +620,7 @@ static void
 grl_opensubtitles_source_resolve (GrlSource            *source,
                                   GrlSourceResolveSpec *rs)
 {
-  GrlOpenSubtitlesSourcePriv *priv =
-    GRL_OPENSUBTITLES_SOURCE_GET_PRIVATE (source);
+  GrlOpenSubtitlesSourcePrivate *priv = GRL_OPENSUBTITLES_SOURCE(source)->priv;
   SoupMessage *msg;
 
   GRL_DEBUG (__FUNCTION__);
@@ -654,8 +648,7 @@ static void
 grl_opensubtitles_source_cancel (GrlSource *source,
                                  guint operation_id)
 {
-  GrlOpenSubtitlesSourcePriv *priv =
-    GRL_OPENSUBTITLES_SOURCE_GET_PRIVATE (source);
+  GrlOpenSubtitlesSourcePrivate *priv = GRL_OPENSUBTITLES_SOURCE (source)->priv;
   SoupMessage *msg = grl_operation_get_data (operation_id);
 
   if (msg)
