@@ -157,10 +157,16 @@ insert_key_mapping (GrlKeyID     grl_key,
                     const gchar *sparql_key_attr_call,
                     const gchar *sparql_key_flavor)
 {
-  tracker_grl_sparql_t *assoc = g_new0 (tracker_grl_sparql_t, 1);
-  GList *assoc_list = g_hash_table_lookup (grl_to_sparql_mapping,
-                                           GRLKEYID_TO_POINTER (grl_key));
-  gchar *canon_name = g_strdup (GRL_METADATA_KEY_GET_NAME (grl_key));
+  tracker_grl_sparql_t *assoc;
+  GList *assoc_list;
+  gchar *canon_name;
+
+  g_return_val_if_fail (grl_key != GRL_METADATA_KEY_INVALID, NULL);
+
+  assoc = g_new0 (tracker_grl_sparql_t, 1);
+  assoc_list = g_hash_table_lookup (grl_to_sparql_mapping,
+                                    GRLKEYID_TO_POINTER (grl_key));
+  canon_name = g_strdup (GRL_METADATA_KEY_GET_NAME (grl_key));
 
   assoc->grl_key               = grl_key;
   assoc->sparql_key_name       = build_flavored_key (canon_name,
@@ -325,11 +331,13 @@ grl_tracker_setup_key_mappings (void)
 		      "(SELECT tracker:referenceIdentifier(?rg) AS ?rg_id { ?urn nmm:musicAlbum ?album . ?album tracker:hasExternalReference ?rg . ?rg tracker:referenceSource \"https://musicbrainz.org/doc/Release_Group\" })",
 		      "audio");
 
-  insert_key_mapping_with_setter (grl_metadata_key_chromaprint,
-                                  NULL,
-                                  "(select nfo:hashValue(?h) { ?urn nfo:hasHash ?h . ?h nfo:hashAlgorithm \"chromaprint\" })",
-                                  "audio",
-                                  set_string_metadata_keys);
+  if (grl_metadata_key_chromaprint != 0) {
+    insert_key_mapping_with_setter (grl_metadata_key_chromaprint,
+                                    NULL,
+                                    "(select nfo:hashValue(?h) { ?urn nfo:hasHash ?h . ?h nfo:hashAlgorithm \"chromaprint\" })",
+                                    "audio",
+                                    set_string_metadata_keys);
+  };
 
   insert_key_mapping (GRL_METADATA_KEY_FRAMERATE,
                       "nfo:frameRate",
@@ -542,7 +550,7 @@ gen_prop_insert_string (GString *gstr,
 
   switch (type) {
   case G_TYPE_STRING:
-    tmp = g_strescape (grl_data_get_string (data, assoc->grl_key), NULL);
+    tmp = tracker_sparql_escape_string (grl_data_get_string (data, assoc->grl_key));
     g_string_append_printf (gstr, "%s \"%s\"",
                             assoc->sparql_key_attr, tmp);
     g_free (tmp);
